//
//  ViewController.m
//  ImageViewer
//
//  Created by Stephen Zaharuk on 4/1/16.
//  Copyright © 2016 Stephen Zaharuk. All rights reserved.
//

#import "ViewController.h"

@interface ViewController ()
{
    IGGridView* _gridView;
    IGGridViewSingleRowSingleFieldDataSourceHelper *_dsh;
}


@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    _gridView = [[IGGridView alloc]initWithFrame:self.view.bounds style:IGGridViewStyleSingleCellPaging];
    _gridView.autoresizingMask = UIViewAutoresizingFlexibleWidth | UIViewAutoresizingFlexibleHeight;
    _gridView.allowHorizontalBounce = YES;
    _gridView.alwaysBounceVertical = NO;
    _gridView.selectionType = IGGridViewSelectionTypeNone;
    [self.view addSubview:_gridView];
    
    NSMutableArray* images = [[NSMutableArray alloc] init];
    for(int i = 1; i <= 26; i++)
    {
        ImageObj* obj = [[ImageObj alloc]init];
        obj.imageName = [NSString stringWithFormat:@"photo%d.jpeg", i];
        obj.isRecentImage = i%3 == 0;
        [images addObject:obj];
    }
    
    CustomImageColumn* col = [[CustomImageColumn alloc]initWithKey:@"image" forPropertyType:IGGridViewImageColumnDefinitionPropertyTypeImage];
    col.loadAsync = YES;
    
    _dsh = [[IGGridViewSingleRowSingleFieldDataSourceHelper alloc]initWithField:col];
    _dsh.data = images;
    
    
    _gridView.dataSource = _dsh;
    
}


@end

@implementation ImageObj

-(UIImage *)image
{
    return [UIImage imageNamed:self.imageName];
}

@end

@implementation CustomImageColumn

-(IGGridViewCell *)gridView:(IGGridView *)gridView createCell:(IGCellPath *)path usingDataSource:(IGGridViewDataSourceHelper *)dataSource
{
    IGGridViewImageCell* cell = (IGGridViewImageCell*)[super gridView:gridView createCell:path usingDataSource:dataSource];
    
    ImageObj* obj = [dataSource resolveDataObjectForRow:path];
    
    cell.imageView.layer.borderWidth = 10;
    cell.imageView.layer.borderColor = obj.isRecentImage?  [UIColor redColor].CGColor : [UIColor whiteColor].CGColor;
    
    return cell;
}


@end

